@@ -2,8 +2,7 @@
 
 
 from ._framework._ScreenModule import _Screen as Screen
-from ._framework._ScreenModule import concat
-
+from ._framework._ScreenModule import concat, read_csv
 from . import _arithmetic as calc
 from . import _experimental_design as design
 from . import _external_tools as tools
@@ -11,3 +10,4 @@ from . import _normalization as norm
 from . import _utilities as util
 from . import _readwrite as io
 from . import _plotting as pl
+from . import _qc as qc
